Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(919)

Unified Diff: third_party/WebKit/Source/modules/webaudio/AudioNode.h

Issue 2103043007: Rename AbstractAudioContext to BaseAudioContext (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Use ASSERT(isGraphOwner()) instead of DCHECK Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/modules/webaudio/AudioNode.h
diff --git a/third_party/WebKit/Source/modules/webaudio/AudioNode.h b/third_party/WebKit/Source/modules/webaudio/AudioNode.h
index 9d7fda8145f750000468f0b18a9ddcd29524e1f8..2c120125079cf5e5d3af57964750d38e0a0023d7 100644
--- a/third_party/WebKit/Source/modules/webaudio/AudioNode.h
+++ b/third_party/WebKit/Source/modules/webaudio/AudioNode.h
@@ -39,14 +39,14 @@
namespace blink {
-class AbstractAudioContext;
+class BaseAudioContext;
class AudioNode;
class AudioNodeInput;
class AudioNodeOutput;
class AudioParam;
class ExceptionState;
// An AudioNode is the basic building block for handling audio within an AbstractAudioContext.
// It may be an audio source, an intermediate processing module, or an audio destination.
// Each AudioNode can have inputs and/or outputs. An AudioSourceNode has no inputs and a single output.
// An AudioDestinationNode has one input and no outputs and represents the final destination to the audio hardware.
@@ -105,11 +105,11 @@ public:
// nullptr after dispose(). We must not call node() in an audio rendering
// thread.
AudioNode* node() const;
// context() returns a valid object until the AbstractAudioContext dies, and returns
// nullptr otherwise. This always returns a valid object in an audio
// rendering thread, and inside dispose(). We must not call context() in
// the destructor.
- virtual AbstractAudioContext* context() const;
+ virtual BaseAudioContext* context() const;
void clearContext() { m_context = nullptr; }
enum ChannelCountMode {
@@ -245,10 +245,10 @@ private:
UntracedMember<AudioNode> m_node;
// This untraced member is safe because this is cleared for all of live
// AudioHandlers when the AbstractAudioContext dies. Do not access m_context
// directly, use context() instead.
// See http://crbug.com/404527 for the detail.
- UntracedMember<AbstractAudioContext> m_context;
+ UntracedMember<BaseAudioContext> m_context;
float m_sampleRate;
Vector<std::unique_ptr<AudioNodeInput>> m_inputs;
@@ -295,7 +295,7 @@ public:
void disconnect(AudioNode*, unsigned outputIndex, unsigned inputIndex, ExceptionState&);
void disconnect(AudioParam*, ExceptionState&);
void disconnect(AudioParam*, unsigned outputIndex, ExceptionState&);
- AbstractAudioContext* context() const;
+ BaseAudioContext* context() const;
unsigned numberOfInputs() const;
unsigned numberOfOutputs() const;
unsigned long channelCount() const;
@@ -316,7 +316,7 @@ public:
void disconnectWithoutException(unsigned outputIndex);
protected:
- explicit AudioNode(AbstractAudioContext&);
+ explicit AudioNode(BaseAudioContext&);
// This should be called in a constructor.
void setHandler(PassRefPtr<AudioHandler>);
@@ -328,7 +328,7 @@ private:
// Returns true if the specified AudioParam was connected.
bool disconnectFromOutputIfConnected(unsigned outputIndex, AudioParam&);
- Member<AbstractAudioContext> m_context;
+ Member<BaseAudioContext> m_context;
RefPtr<AudioHandler> m_handler;
// Represents audio node graph with Oilpan references. N-th HeapHashSet
// represents a set of AudioNode objects connected to this AudioNode's N-th
@@ -39,14 +39,14 @@
class AudioParam;
class ExceptionState;
-// An AudioNode is the basic building block for handling audio within an AbstractAudioContext.
+// An AudioNode is the basic building block for handling audio within an BaseAudioContext.
// It may be an audio source, an intermediate processing module, or an audio destination.
// Each AudioNode can have inputs and/or outputs. An AudioSourceNode has no inputs and a single output.
@@ -105,11 +105,11 @@ public:
// thread.
AudioNode* node() const;
- // context() returns a valid object until the AbstractAudioContext dies, and returns
+ // context() returns a valid object until the BaseAudioContext dies, and returns
// nullptr otherwise. This always returns a valid object in an audio
// rendering thread, and inside dispose(). We must not call context() in
@@ -245,10 +245,10 @@ private:
UntracedMember<AudioNode> m_node;
// This untraced member is safe because this is cleared for all of live
- // AudioHandlers when the AbstractAudioContext dies. Do not access m_context
+ // AudioHandlers when the BaseAudioContext dies. Do not access m_context
// directly, use context() instead.
// See http://crbug.com/404527 for the detail.
« no previous file with comments | « third_party/WebKit/Source/modules/webaudio/AudioListener.cpp ('k') | third_party/WebKit/Source/modules/webaudio/AudioNode.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698